@@ -380,7 +380,7 @@ void draw_home_window(gint count_day){
 	break;
 	case TINY:
 	    icon_size = TINY_ICON_SIZE;
-	break;        
+	break;
     }
     memset(temperature_string, 0, sizeof(temperature_string));
     memset(forecast_string, 0, sizeof(forecast_string));
@@ -406,8 +406,8 @@ void draw_home_window(gint count_day){
 	i = 0;
 	while(tmp && i < offset){
 	    day = (GSList*)tmp->data;
+	    tmp = g_slist_remove(tmp,day);
 	    destroy_object(&day);
-	    tmp = g_slist_next(tmp);
 	    i++;
 	}
 	app->wsd.days = tmp;
@@ -415,7 +415,7 @@ void draw_home_window(gint count_day){
 	if (app->wsd.days){
 	    first = (GSList*)((app->wsd.days)->data);
 	    last = (GSList*)((g_slist_last(tmp))->data);
-	}    
+	}
     }
 
     i = 0;
@@ -483,8 +483,16 @@ void draw_home_window(gint count_day){
 	    }
 	    else{/* other days, from two and to app->config->days_to_show */
 		buffer[0] = 0;
-		(app->config->separate && i == 1) ? (tmp_day = first) : (tmp_day = day);
+		if (app->config->separate && i == 1){
+		     tmp_day = first;
+		     /* Change day and nitght  begin  time */
+		    day_begin_time = get_day_part_begin_time(tmp_day, year, "24h_sunrise");
+		    night_begin_time = get_day_part_begin_time(tmp_day, year, "24h_sunset");
+		}else
+		     tmp_day = day;		      
+		     
 		create_day_temperature_text(tmp_day, buffer, FALSE, FALSE);
+		
 		if((app->config->separate) && (i == 1) &&
 		   (current_time > night_begin_time || current_time < day_begin_time)){
 		    if(app->config->show_wind)
@@ -530,7 +538,6 @@ void draw_home_window(gint count_day){
 						    app->config->transparency,
 						    TRUE,
 						    &(app->config->background_color));
-//	g_signal_connect(tmp_button->button, "button-release-event",
 	g_signal_connect(tmp_button->button, "button-press-event",
 			    G_CALLBACK(weather_window_popup),
 			    (is_na_day ? (GINT_TO_POINTER(-1)) : (GINT_TO_POINTER(i))));
@@ -597,7 +604,10 @@ void redraw_home_window(gboolean first_start){
 	tmp = app->buttons;
 	while(tmp){
 	    tmp_button = (WDB*)tmp->data;
-	    delete_weather_day_button(&tmp_button);
+	    if (tmp_button){
+		delete_weather_day_button(&tmp_button);
+		tmp_button = NULL;
+	    }
 	    tmp = g_slist_next(tmp);
 	}
 	g_slist_free(app->buttons);
@@ -620,6 +630,9 @@ void redraw_home_window(gboolean first_start){
     } /* Error in xml file */
     app->count_day = count_day;	/* store days number from xml file */
     draw_home_window(count_day);
+#ifdef DEBUGFUNCTIONCALL
+    STOP_FUNCTION;
+#endif
 }
 /*******************************************************************************/
 gboolean remitted_update(void){
@@ -700,6 +713,7 @@ void* hildon_home_applet_lib_initialize(void *state_data, int *state_size,
     }
     app->time_update_list = create_time_update_list();
     app->show_update_window = FALSE;
+    app->contextmenu = NULL;
 /* Read Coutries list from file */
     app->countrys_list
 	= create_items_list(weather_sources[app->config->weather_source].db_path,
@@ -801,14 +815,15 @@ void hildon_home_applet_lib_deinitialize(void *applet_data){
         g_signal_handler_disconnect(app->top_widget,app->signal_expose);
         if(app->pixbuf){ 
 	    gdk_pixbuf_unref(app->pixbuf);
-	    app->pixbuf = NULL; 
+	    app->pixbuf = NULL;
 	}
 #endif	
-			
+		
     osso = (osso_context_t*)applet_data;
     
     if(app){
-	app->top_widget = NULL;    
+	app->top_widget = NULL;
+	app->main_window = NULL;
 	free_memory();
 	if(app->config)
     	    g_free(app->config);
@@ -1460,12 +1475,21 @@ void free_memory(void){
     tmp = app->buttons;
     while(tmp){
 	tmp_button = (WDB*)tmp->data;
-	delete_weather_day_button(&tmp_button);
+	if (tmp_button){
+	    delete_weather_day_button(&tmp_button);
+	    tmp_button = NULL;
+	}
 	tmp = g_slist_next(tmp);
     }
     g_slist_free(app->buttons);
     app->buttons = NULL;
 
+    /* Free config->cache_directory */
+    if (app->config->cache_directory){
+	g_free (app->config->cache_directory);
+	app->config->cache_directory = NULL;
+    }
+
     if(app->config->cache_dir_name){
         g_free(app->config->cache_dir_name);
         app->config->cache_dir_name = NULL;
@@ -1562,24 +1586,7 @@ void delete_weather_day_button(WDB **day){
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-    return;
     if(*day){
-	if((*day)->icon_image && GTK_IS_WIDGET((*day)->icon_image)){
-	    gtk_widget_destroy( (*day)->icon_image );
-	    (*day)->icon_image = NULL;
-	}
-	if((*day)->label && GTK_IS_WIDGET((*day)->label)){
-	    gtk_widget_destroy( (*day)->label );    
-	    (*day)->label = NULL;
-	}    
-	if((*day)->box && GTK_IS_WIDGET((*day)->box)){
-	    gtk_widget_destroy( (*day)->box );
-	    (*day)->box = NULL;
-	}    
-	if((*day)->button && GTK_IS_WIDGET((*day)->button)){
-	    gtk_widget_destroy( (*day)->button );
-	    (*day)->button = NULL;
-	}    
 	g_free(*day);
 	*day = NULL;
     }
@@ -1843,6 +1850,7 @@ omweather_init(OMWeather *applet){
         return;
     }
     app->popup_window = NULL;
+    app->contextmenu = NULL;
     app->tab_of_window_popup = NULL;
     app->time_update_list = create_time_update_list();
     app->show_update_window = FALSE;
