@@ -231,7 +231,7 @@ gboolean make_current_tab(GtkWidget *vbox)
 gboolean make_tab(GtkWidget *vbox)
 {
         GSList	*day = NULL;
-        gchar	*day_name = NULL;
+        gchar  *day_name = NULL;
 	GtkWidget *child;
 	if (app->popup_window){
 	    day = (GSList*)g_object_get_data(G_OBJECT(vbox), "day");
@@ -241,6 +241,7 @@ gboolean make_tab(GtkWidget *vbox)
 		gtk_widget_show_all(vbox);
 	    }else
 	        gtk_widget_destroy(GTK_WIDGET(child));
+	    g_free(day_name);
 	}    
 	return FALSE;
 }
@@ -261,7 +262,7 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
 		k = 0,
 		page = 0,
 		i = 1;
-    gchar	*day_name = NULL;
+    gchar  	*day_name = NULL;
     time_t      current_time = 0,
                 diff_time,
                 current_data_last_update = 0;
@@ -276,7 +277,7 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
     active_tab = (gint)user_data;
 /* if no one station present in list show settings window */
     if(!app->config->current_station_id){
-	weather_window_settings(NULL, NULL, (gpointer)active_tab);
+	weather_window_settings(NULL, (gpointer)active_tab);
 	return FALSE;
     }
 /* Main window */
@@ -362,7 +363,10 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
         				gtk_label_new(day_name));
 		}
 	}
-	day_name && (g_free(day_name), day_name = NULL);
+	if (day_name){
+	    g_free(day_name);
+	    day_name = NULL;
+	}
 	tmp = g_slist_next(tmp);
 	i++;
     }
@@ -473,7 +477,7 @@ void settings_button_handler(GtkWidget *button, GdkEventButton *event,
 /* For debug speed of creating setting window */
 /* time_start();  */
     destroy_popup_window();
-    weather_window_settings(NULL, NULL, (gpointer)day_number);
+    weather_window_settings(NULL, (gpointer)day_number);
 /* fprintf(stderr,"Time: %lf msec Pi = %lf\n",time_stop(),weather_window_settings);*/
 }
 /*******************************************************************************/
@@ -881,7 +885,8 @@ GtkWidget* create_current_tab(GSList *current){
 GtkWidget* create_copyright_widget(const gchar *text, const gchar *image){
     GtkWidget	*main_widget = NULL,
 		*hbox = NULL,
-		*label= NULL,
+		*label = NULL,
+		*separator = NULL,
 		*icon = NULL;
     GdkPixbuf   *icon_buffer = NULL;
     gchar	image_buffer[512],
@@ -915,8 +920,9 @@ GtkWidget* create_copyright_widget(const gchar *text, const gchar *image){
 	if(icon)
 	    gtk_box_pack_start(GTK_BOX(hbox), icon, FALSE, FALSE, 0);
     }
+    separator = gtk_hseparator_new();
     gtk_box_pack_start(GTK_BOX(main_widget), hbox, FALSE, FALSE, 5);
-    gtk_box_pack_start(GTK_BOX(main_widget), gtk_hseparator_new(), FALSE, TRUE, 5);
+    gtk_box_pack_start(GTK_BOX(main_widget), separator, FALSE, TRUE, 5);
     return main_widget;
 }
 /*******************************************************************************/
